# Atendimento

## Quality Gate
- Resposta deve ser clara, objetiva e em português
- Se baseada em documento da KB, deve citar a fonte
- Resposta não deve contradizer documentação existente
- Se não encontrou solução, deve informar claramente ao usuário

## Veto Conditions
- Resposta que contradiz documentação da knowledge base
- Resposta técnica sem embasamento (inventar solução)
- Expor dados internos do sistema ao usuário
